Responses — Django RPC 0.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Django RPC 0.1 documentation »
- API Guide »

# Responses

class `djangorpc.responses.` `RpcResponse`

  Bases: `dict`

  Base class for rpc response clasess

class `djangorpc.responses.` `Error`(text, **kwargs)

  Bases: `djangorpc.responses.RpcResponse`

  Simple responses. Just for pretty code and some kind of “protocol”. Example:

      return Error('Something happened', code=error_code, traceback=traceback)

class `djangorpc.responses.` `Msg`(text, **kwargs)

  Bases: `djangorpc.responses.RpcResponse`

  Simple responses. Just for pretty code and some kind of “protocol”. Example:

      return Msg('Object saved!')

class `djangorpc.responses.` `RpcHttpResponse`(*args, **kwargs)

  Bases: `djangorpc.responses.RpcResponse`

  This is vrapper for method’s reponse, which allow save some modification of HTTP response. For example set COOKIES. This should be flexible and useful for in future.

### Navigation

- index
- modules |
- next |
- previous |
- Django RPC 0.1 documentation »
- API Guide »